@@ -28,6 +28,21 @@ spread_.data.table <- function(data, key_col, value_col, fill = NA, convert = FA
   data2
 }
 
+
+
+shallow <- function(x,...){
+  shallow_(x = x, vars = lazyeval::lazy_dots(...))
+}
+shallow_ <- function(x, vars) {
+    vars <- names(select_vars_(names(x), vars))
+    if (length(vars) == 0) {
+       vars <- names(x)
+    }
+    out = as.list(x)[vars]
+    setDT(out)
+    out
+}
+
 ##' @export
 ##' @method spread_ tbl_dt
 #spread_.tbl_dt <- function(data, key_col, value_col, fill = NA, convert = FALSE, drop = TRUE) {
